#
from inc_cfg import *

test_param = TestParam(
		"Callee=mandatory SRTP, caller=mandatory SRTP with DTLS keying",
		[
			InstanceParam("callee", "--null-audio --use-srtp=2 --srtp-secure=0 --max-calls=1"),
			InstanceParam("caller", "--null-audio --use-srtp=2 --srtp-secure=0 --max-calls=1 --srtp-keying=1")
		]
		)



#
from inc_cfg import *

test_param = TestParam(
		"Callee=optional SRTP, caller=mandatory SRTP",
		[
			InstanceParam("callee", "--null-audio --use-srtp=1 --srtp-secure=0 --max-calls=1"),
			InstanceParam("caller", "--null-audio --use-srtp=2 --srtp-secure=0 --max-calls=1")
		]
		)



#
from inc_cfg import *

# Regular ICE vs trickle ICE full, should be okay (as trickle will be disabled)
test_param = TestParam(
		"Callee=Trickle ICE (full), caller=Regular ICE",
		[
			InstanceParam("callee", "--null-audio --max-calls=1 --use-ice --ice-trickle=2 --stun-srv stun.pjsip.org"),
			InstanceParam("caller", "--null-audio --max-calls=1 --use-ice --ice-trickle=0 --stun-srv stun.pjsip.org")
		]
		)
